@@ -33,7 +33,7 @@ use warnings 'once';
 
 use Cwd 'abs_path';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use App::LXC::Container::Texts;
 
@@ -448,11 +448,6 @@ sub content_x11_packages($)
 sub depends_on($$$)
 {
     my $self = _check_singleton(shift);
-    my ($package, $all) = @_;
-    defined $self->{CHECKED}  or  $self->{CHECKED} = {};
-    defined $self->{CHECKED}{$package}  or   $self->{CHECKED}{$package} = 0;
-    $self->{CHECKED}{$package}++;
-    return ();
 }
 
 #########################################################################
